@@ -532,7 +532,7 @@ hig_dialog_new (GtkWindow      *parent,
 	GtkWidget *vbox;
 	GtkWidget *label;
 	GtkWidget *button;
-	GtkWidget *image;
+	GtkWidget *image = NULL;
 	gchar     *title;
 
 	dialog = gtk_dialog_new ();
@@ -2445,7 +2445,7 @@ mailcheck_about(BonoboUIComponent *uic, MailCheck *mc, const gchar *verbname)
 	pixbuf = gdk_pixbuf_new_from_file (file, NULL);
 	g_free (file);
 	
-	mc->about = gnome_about_new (_("Inbox Monitor"), "1.1",
+	mc->about = gnome_about_new (_("Inbox Monitor"), VERSION,
 				     "Copyright \xc2\xa9 1998-2002 Free Software Foundation, Inc.",
 				     _("Inbox Monitor notifies you when new mail arrives in your mailbox"),
 				     authors,
